@@ -26,3 +26,11 @@
 #' @docType package
 #' @import stats
 NULL
+
+#' @useDynLib imputeTS
+#' @importFrom Rcpp sourceCpp
+NULL
+
+.onUnload <- function (libpath) {
+  library.dynam.unload("imputeTS", libpath)
+}
